textstats_parametererrortest
open | / |
type | projectname | seleniumtest
clickAndWait | startprojectbutton |
click | openeditor |
select | editorinputtemplate | label=Input text document
select | language | label=Dutch
type | editorfilename | test
type | editorcontents | Dit is een test.
click | editorsubmit |
type | freqlistlimit | -34
click | //input[@value='Start'] |
waitForTextPresent | exact:Error: One or more parameters are invalid |
verifyTextPresent | Number must be a whole number between 0 and 99999999 |
clickAndWait | abortbutton |
verifyTextPresent | Start a new Project |